@@ -6,4 +6,4 @@ cd $(dirname "$0")
 echo "*********************************************"
 echo "Connect to OpenOCD via: telnet localhost $(awk '/^telnet_port/{print$2}' $CONFIG_GEN)"
 echo "*********************************************"
-openocd -f $CONFIG_GEN -f $CONFIG_IF -f $CONFIG_CHIP
+openocd -f $CONFIG_GEN -f $CONFIG_IF -f $CONFIG_BOARD
